@@ -1,9 +1,10 @@
 import os
 import serial
-from .MyUtil import MyUtil as util
-from .MyCore import MyCore
+from .MyUtil import MyUtil
+from .MySerial import MySerial
 import shutil
 import urllib.request
+import time
 
 
 class WBUpload(object):
@@ -11,7 +12,7 @@ class WBUpload(object):
         '''
         direct append to last of the wb_ampy
         '''
-        port = MyCore.choose_serial()
+        port = MySerial.choose_serial()
         if not info is None:
             print(info)
         if port != None:
@@ -23,7 +24,7 @@ class WBUpload(object):
         '''
         if not self._is_empty(file_path):
             try:
-                port = MyCore.choose_serial()
+                port = MySerial.choose_serial()
                 if port != None:
                     currentDir = os.getcwd()
                     source_file_path = file_path
@@ -34,10 +35,30 @@ class WBUpload(object):
                     os.system('wb_ampy -d 2 -p {}  put {} main.py'.format(
                         port, source_file_path))
                     # print('_____________________________________')
-                    ser = serial.Serial(port, 115200, timeout=1)
-                    # reset pyboard manully in windows, because windows system do not reset automatically in first connection.
-                    ser.write(b'\x04')
+
                     print('下载结束')
+                try:
+                    if port != None:
+                        ser = MySerial()
+                        # reset pyboard manully in windows, because windows system do not reset automatically in first connection.
+                        ser.write(b'\x04')
+                        MyUtil.wb_log(
+                            '@rec@ ',
+                            ser.read_and_compare('wb init end.\r\n', 5, False))
+                        print('开始运行，按Ctrl+C结束')
+                        # print('_______________________________________')
+                        while True:
+                            buffer = ser.read()
+                            print(buffer, end='')
+                            time.sleep(0.01)
+                except KeyboardInterrupt as err:
+                    for i in range(3):
+                        ser.write(b'\x03')
+                    print('运行结束')
+
+                except Exception as e:
+                    print('读出输出失败', e)
+                finally:
                     ser.close()
 
             except OSError as e:
@@ -48,7 +69,7 @@ class WBUpload(object):
     def put(self, source_file_path, designation_file_path):
         if not self._is_empty(source_file_path):
             try:
-                port = MyCore.choose_serial()
+                port = MySerial.choose_serial()
                 if port != None:
                     currentDir = os.getcwd()
                     # source_file_path = file_path
@@ -94,13 +115,13 @@ class WBUpload(object):
                 download_url = 'http://wonderbits.cn:3939/board/{}?version={}'.format(
                     folder, version)
                 des_bin_file = './wb.bin'
-                util.wb_log(download_url, '\n')
+                MyUtil.wb_log(download_url, '\n')
                 urllib.request.urlretrieve(download_url, des_bin_file)
                 pass
 
             # print(download_url)
             print('上传固件。。。')
-            port = MyCore.choose_serial()
+            port = MySerial.choose_serial()
             if port != None:
                 # os.system('esptool.py --port ' + port + ' erase_flash')
                 os.system('esptool.py --chip esp32 --port ' + port +
@@ -133,7 +154,7 @@ class WBUpload(object):
 
             return version_list
 
-        util.wb_log('http://wonderbits.cn:3939/versions/' + folder, '\n')
+        MyUtil.wb_log('http://wonderbits.cn:3939/versions/' + folder, '\n')
         with urllib.request.urlopen('http://wonderbits.cn:3939/versions/' +
                                     folder) as f:
             text = f.read()
